/* $Id: glapitemp.h,v 1.1 1999/11/25 18:16:13 brianp Exp $ */

/*
 * Mesa 3-D graphics library
 * Version:  3.3
 * 
 * Copyright (C) 1999  Brian Paul   All Rights Reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * BRIAN PAUL BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */


/*
 * This file is a template which generates the OpenGL API entry point
 * functions.  It should be included by a .c file which first defines
 * the following macros:
 *   KEYWORD1 - usually nothing, but might be __declspec(dllexport) on Win32
 *   KEYWORD2 - usually nothing, but might be __stdcall on Win32
 *   NAME(n)  - builds the final function name (usually add "gl" prefix)
 *   DISPATCH_SETUP - code needed to setup function dispatch
 *   DISPATCH(func, args) - code to do actual dispatch of named function
 *
 * Here's an example which generates the usual OpenGL functions:
 *   #define KEYWORD1
 *   #define KEYWORD2
 *   #define NAME(func)  gl##func
 *   #define DISPATCH_SETUP  struct _glapi_table *dispatch = CurrentDispatch;
 *   #define DISPATCH(func, args)  (*dispatch->func) args
 *
 * Furthermore, sets of entrypoints (extensions) can selectively be
 * generated by defining the following symbols before including this
 * file:
 *
 *   _GLAPI_VERSION_1_1       - generate 1.1 functions
 *   _GLAPI_VERSION_1_2       - generate 1.2 functions
 *   _GLAPI_ARB_imaging       - generate 1.2 imaging functions
 *   _GLAPI_ARB_multitexture  - generate 1.2 multi-texture functions
 *   _GLAPI_EXT_paletted_texture
 *   _GLAPI_EXT_compiled_vertex_array
 *   _GLAPI_EXT_point_parameters
 *   _GLAPI_EXT_polygon_offset
 *   _GLAPI_EXT_blend_minmax
 *   _GLAPI_EXT_blend_color
 *   _GLAPI_EXT_texture3
 *   _GLAPI_EXT_texture_object
 *   _GLAPI_EXT_vertex_array
 *   _GLAPI_INGR_blend_func_separate
 *   _GLAPI_MESA_window_pos
 *   _GLAPI_MESA_resize_buffers
 *   etc...
 */




KEYWORD1 void KEYWORD2 NAME(Accum)(GLenum op, GLfloat value)
{
   DISPATCH_SETUP;
   DISPATCH(Accum, (op, value));
}

KEYWORD1 void KEYWORD2 NAME(AlphaFunc)(GLenum func, GLclampf ref)
{
   DISPATCH_SETUP;
   DISPATCH(AlphaFunc, (func, ref));
}

KEYWORD1 void KEYWORD2 NAME(Begin)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(Begin, (mode));
}

KEYWORD1 void KEYWORD2 NAME(Bitmap)(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)
{
   DISPATCH_SETUP;
   DISPATCH(Bitmap, (width, height, xorig, yorig, xmove, ymove, bitmap));
}

KEYWORD1 void KEYWORD2 NAME(BlendFunc)(GLenum sfactor, GLenum dfactor)
{
   DISPATCH_SETUP;
   DISPATCH(BlendFunc, (sfactor, dfactor));
}

KEYWORD1 void KEYWORD2 NAME(CallList)(GLuint list)
{
   DISPATCH_SETUP;
   DISPATCH(CallList, (list));
}

KEYWORD1 void KEYWORD2 NAME(CallLists)(GLsizei n, GLenum type, const GLvoid *lists)
{
   DISPATCH_SETUP;
   DISPATCH(CallLists, (n, type, lists));
}

KEYWORD1 void KEYWORD2 NAME(Clear)(GLbitfield mask)
{
   DISPATCH_SETUP;
   DISPATCH(Clear, (mask));
}

KEYWORD1 void KEYWORD2 NAME(ClearAccum)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   DISPATCH_SETUP;
   DISPATCH(ClearAccum, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(ClearColor)(GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha)
{
   DISPATCH_SETUP;
   DISPATCH(ClearColor, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(ClearDepth)(GLclampd depth)
{
   DISPATCH_SETUP;
   DISPATCH(ClearDepth, (depth));
}

KEYWORD1 void KEYWORD2 NAME(ClearIndex)(GLfloat c)
{
   DISPATCH_SETUP;
   DISPATCH(ClearIndex, (c));
}

KEYWORD1 void KEYWORD2 NAME(ClearStencil)(GLint s)
{
   DISPATCH_SETUP;
   DISPATCH(ClearStencil, (s));
}

KEYWORD1 void KEYWORD2 NAME(ClipPlane)(GLenum plane, const GLdouble *equation)
{
   DISPATCH_SETUP;
   DISPATCH(ClipPlane, (plane, equation));
}

KEYWORD1 void KEYWORD2 NAME(Color3b)(GLbyte red, GLbyte green, GLbyte blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3b, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3d)(GLdouble red, GLdouble green, GLdouble blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3d, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3f)(GLfloat red, GLfloat green, GLfloat blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3f, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3i)(GLint red, GLint green, GLint blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3i, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3s)(GLshort red, GLshort green, GLshort blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3s, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3ub)(GLubyte red, GLubyte green, GLubyte blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3ub, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3ui)(GLuint red, GLuint green, GLuint blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3ui, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color3us)(GLushort red, GLushort green, GLushort blue)
{
   DISPATCH_SETUP;
   DISPATCH(Color3us, (red, green, blue));
}

KEYWORD1 void KEYWORD2 NAME(Color4b)(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4b, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4d)(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4d, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4f)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4f, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4i)(GLint red, GLint green, GLint blue, GLint alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4i, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4s)(GLshort red, GLshort green, GLshort blue, GLshort alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4s, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4ub)(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4ub, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4ui)(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4ui, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color4us)(GLushort red, GLushort green, GLushort blue, GLushort alpha)
{
   DISPATCH_SETUP;
   DISPATCH(Color4us, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(Color3bv)(const GLbyte *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3bv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3ubv)(const GLubyte *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3ubv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3uiv)(const GLuint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3uiv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color3usv)(const GLushort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color3usv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4bv)(const GLbyte *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4bv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4ubv)(const GLubyte *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4ubv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4uiv)(const GLuint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4uiv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Color4usv)(const GLushort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Color4usv, (v));
}

KEYWORD1 void KEYWORD2 NAME(ColorMask)(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   DISPATCH_SETUP;
   DISPATCH(ColorMask, (red, green, blue, alpha));
}

KEYWORD1 void KEYWORD2 NAME(ColorMaterial)(GLenum face, GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(ColorMaterial, (face, mode));
}

KEYWORD1 void KEYWORD2 NAME(CopyPixels)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)
{
   DISPATCH_SETUP;
   DISPATCH(CopyPixels, (x, y, width, height, type));
}

KEYWORD1 void KEYWORD2 NAME(CullFace)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(CullFace, (mode));
}

KEYWORD1 void KEYWORD2 NAME(DepthFunc)(GLenum func)
{
   DISPATCH_SETUP;
   DISPATCH(DepthFunc, (func));
}

KEYWORD1 void KEYWORD2 NAME(DepthMask)(GLboolean flag)
{
   DISPATCH_SETUP;
   DISPATCH(DepthMask, (flag));
}

KEYWORD1 void KEYWORD2 NAME(DepthRange)(GLclampd nearVal, GLclampd farVal)
{
   DISPATCH_SETUP;
   DISPATCH(DepthRange, (nearVal, farVal));
}

KEYWORD1 void KEYWORD2 NAME(DeleteLists)(GLuint list, GLsizei range)
{
   DISPATCH_SETUP;
   DISPATCH(DeleteLists, (list, range));
}

KEYWORD1 void KEYWORD2 NAME(Disable)(GLenum cap)
{
   DISPATCH_SETUP;
   DISPATCH(Disable, (cap));
}

KEYWORD1 void KEYWORD2 NAME(DrawBuffer)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(DrawBuffer, (mode));
}

KEYWORD1 void KEYWORD2 NAME(DrawElements)(GLenum mode, GLsizei count, GLenum type, const GLvoid *indices)
{
   DISPATCH_SETUP;
   DISPATCH(DrawElements, (mode, count, type, indices));
}

KEYWORD1 void KEYWORD2 NAME(DrawPixels)(GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(DrawPixels, (width, height, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(Enable)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(Enable, (mode));
}

KEYWORD1 void KEYWORD2 NAME(End)(void)
{
   DISPATCH_SETUP;
   DISPATCH(End, ());
}

KEYWORD1 void KEYWORD2 NAME(EndList)(void)
{
   DISPATCH_SETUP;
   DISPATCH(EndList, ());
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord1d)(GLdouble u)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord1d, (u));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord1f)(GLfloat u)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord1f, (u));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord1dv)(const GLdouble *u)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord1dv, (u));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord1fv)(const GLfloat *u)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord1fv, (u));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord2d)(GLdouble u, GLdouble v)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord2d, (u, v));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord2f)(GLfloat u, GLfloat v)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord2f, (u, v));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord2dv)(const GLdouble *u)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord2dv, (u));
}

KEYWORD1 void KEYWORD2 NAME(EvalCoord2fv)(const GLfloat *u)
{
   DISPATCH_SETUP;
   DISPATCH(EvalCoord2fv, (u));
}

KEYWORD1 void KEYWORD2 NAME(EvalPoint1)(GLint i)
{
   DISPATCH_SETUP;
   DISPATCH(EvalPoint1, (i));
}

KEYWORD1 void KEYWORD2 NAME(EvalPoint2)(GLint i, GLint j)
{
   DISPATCH_SETUP;
   DISPATCH(EvalPoint2, (i, j));
}

KEYWORD1 void KEYWORD2 NAME(EvalMesh1)(GLenum mode, GLint i1, GLint i2)
{
   DISPATCH_SETUP;
   DISPATCH(EvalMesh1, (mode, i1, i2));
}

KEYWORD1 void KEYWORD2 NAME(EdgeFlag)(GLboolean flag)
{
   DISPATCH_SETUP;
   DISPATCH(EdgeFlag, (flag));
}

KEYWORD1 void KEYWORD2 NAME(EdgeFlagv)(const GLboolean *flag)
{
   DISPATCH_SETUP;
   DISPATCH(EdgeFlagv, (flag));
}

KEYWORD1 void KEYWORD2 NAME(EvalMesh2)(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)
{
   DISPATCH_SETUP;
   DISPATCH(EvalMesh2, (mode, i1, i2, j1, j2));
}

KEYWORD1 void KEYWORD2 NAME(FeedbackBuffer)(GLsizei size, GLenum type, GLfloat *buffer)
{
   DISPATCH_SETUP;
   DISPATCH(FeedbackBuffer, (size, type, buffer));
}

KEYWORD1 void KEYWORD2 NAME(Finish)(void)
{
   DISPATCH_SETUP;
   DISPATCH(Finish, ());
}

KEYWORD1 void KEYWORD2 NAME(Flush)(void)
{
   DISPATCH_SETUP;
   DISPATCH(Flush, ());
}

KEYWORD1 void KEYWORD2 NAME(Fogf)(GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(Fogf, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(Fogi)(GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(Fogi, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(Fogfv)(GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(Fogfv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(Fogiv)(GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(Fogiv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(FrontFace)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(FrontFace, (mode));
}

KEYWORD1 void KEYWORD2 NAME(Frustum)(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble nearval, GLdouble farval)
{
   DISPATCH_SETUP;
   DISPATCH(Frustum, (left, right, bottom, top, nearval, farval));
}

KEYWORD1 GLuint KEYWORD2 NAME(GenLists)(GLsizei range)
{
   DISPATCH_SETUP;
   return DISPATCH(GenLists, (range));
}

KEYWORD1 void KEYWORD2 NAME(GetBooleanv)(GLenum pname, GLboolean *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetBooleanv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetClipPlane)(GLenum plane, GLdouble *equation)
{
   DISPATCH_SETUP;
   DISPATCH(GetClipPlane, (plane, equation));
}

KEYWORD1 void KEYWORD2 NAME(GetDoublev)(GLenum pname, GLdouble *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetDoublev, (pname, params));
}

KEYWORD1 GLenum KEYWORD2 NAME(GetError)(void)
{
   DISPATCH_SETUP;
   return DISPATCH(GetError, ());
}

KEYWORD1 void KEYWORD2 NAME(GetFloatv)(GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetFloatv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetIntegerv)(GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetIntegerv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetLightfv)(GLenum light, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetLightfv, (light, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetLightiv)(GLenum light, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetLightiv, (light, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetMapdv)(GLenum target, GLenum query, GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(GetMapdv, (target, query, v));
}

KEYWORD1 void KEYWORD2 NAME(GetMapfv)(GLenum target, GLenum query, GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(GetMapfv, (target, query, v));
}

KEYWORD1 void KEYWORD2 NAME(GetMapiv)(GLenum target, GLenum query, GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(GetMapiv, (target, query, v));
}

KEYWORD1 void KEYWORD2 NAME(GetMaterialfv)(GLenum face, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetMaterialfv, (face, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetMaterialiv)(GLenum face, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetMaterialiv, (face, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetPixelMapfv)(GLenum map, GLfloat *values)
{
   DISPATCH_SETUP;
   DISPATCH(GetPixelMapfv, (map, values));
}

KEYWORD1 void KEYWORD2 NAME(GetPixelMapuiv)(GLenum map, GLuint *values)
{
   DISPATCH_SETUP;
   DISPATCH(GetPixelMapuiv, (map, values));
}

KEYWORD1 void KEYWORD2 NAME(GetPixelMapusv)(GLenum map, GLushort *values)
{
   DISPATCH_SETUP;
   DISPATCH(GetPixelMapusv, (map, values));
}

KEYWORD1 void KEYWORD2 NAME(GetPolygonStipple)(GLubyte *mask)
{
   DISPATCH_SETUP;
   DISPATCH(GetPolygonStipple, (mask));
}

KEYWORD1 const GLubyte * KEYWORD2 glGetString(GLenum name)
{
   DISPATCH_SETUP;
   return DISPATCH(GetString, (name));
}

KEYWORD1 void KEYWORD2 NAME(GetTexEnvfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexEnvfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexEnviv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexEnviv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexGeniv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexGeniv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexGendv)(GLenum target, GLenum pname, GLdouble *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexGendv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexGenfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexGenfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexImage)(GLenum target, GLint level, GLenum format, GLenum type, GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexImage, (target, level, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(GetTexLevelParameterfv)(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexLevelParameterfv, (target, level, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexLevelParameteriv)(GLenum target, GLint level, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexLevelParameteriv, (target, level, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexParameterfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetTexParameteriv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetTexParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(Hint)(GLenum target, GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(Hint, (target, mode));
}

KEYWORD1 void KEYWORD2 NAME(Indexd)(GLdouble c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexd, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexdv)(const GLdouble *c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexdv, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexf)(GLfloat c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexf, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexfv)(const GLfloat *c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexfv, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexi)(GLint c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexi, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexiv)(const GLint *c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexiv, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexs)(GLshort c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexs, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexsv)(const GLshort *c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexsv, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexub)(GLubyte c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexub, (c));
}

KEYWORD1 void KEYWORD2 NAME(Indexubv)(const GLubyte *c)
{
   DISPATCH_SETUP;
   DISPATCH(Indexubv, (c));
}

KEYWORD1 void KEYWORD2 NAME(IndexMask)(GLuint mask)
{
   DISPATCH_SETUP;
   DISPATCH(IndexMask, (mask));
}

KEYWORD1 void KEYWORD2 NAME(InitNames)(void)
{
   DISPATCH_SETUP;
   DISPATCH(InitNames, ());
}

KEYWORD1 void KEYWORD2 NAME(InterleavedArrays)(GLenum format, GLsizei stride, const GLvoid *pointer)
{
   DISPATCH_SETUP;
   DISPATCH(InterleavedArrays, (format, stride, pointer));
}

KEYWORD1 GLboolean KEYWORD2 NAME(IsEnabled)(GLenum cap)
{
   DISPATCH_SETUP;
   return DISPATCH(IsEnabled, (cap));
}

KEYWORD1 GLboolean KEYWORD2 NAME(IsList)(GLuint list)
{
   DISPATCH_SETUP;
   return DISPATCH(IsList, (list));
}

KEYWORD1 GLboolean KEYWORD2 NAME(IsTexture)(GLuint texture)
{
   DISPATCH_SETUP;
   return DISPATCH(IsTexture, (texture));
}

KEYWORD1 void KEYWORD2 NAME(Lightf)(GLenum light, GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(Lightf, (light, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(Lighti)(GLenum light, GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(Lighti, (light, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(Lightfv)(GLenum light, GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(Lightfv, (light, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(Lightiv)(GLenum light, GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(Lightiv, (light, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(LightModelf)(GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(LightModelf, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(LightModeli)(GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(LightModeli, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(LightModelfv)(GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(LightModelfv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(LightModeliv)(GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(LightModeliv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(LineWidth)(GLfloat width)
{
   DISPATCH_SETUP;
   DISPATCH(LineWidth, (width));
}

KEYWORD1 void KEYWORD2 NAME(LineStipple)(GLint factor, GLushort pattern)
{
   DISPATCH_SETUP;
   DISPATCH(LineStipple, (factor, pattern));
}

KEYWORD1 void KEYWORD2 NAME(ListBase)(GLuint base)
{
   DISPATCH_SETUP;
   DISPATCH(ListBase, (base));
}

KEYWORD1 void KEYWORD2 NAME(LoadIdentity)(void)
{
   DISPATCH_SETUP;
   DISPATCH(LoadIdentity, ());
}

KEYWORD1 void KEYWORD2 NAME(LoadMatrixd)(const GLdouble *m)
{
   DISPATCH_SETUP;
   DISPATCH(LoadMatrixd, (m));
}

KEYWORD1 void KEYWORD2 NAME(LoadMatrixf)(const GLfloat *m)
{
   DISPATCH_SETUP;
   DISPATCH(LoadMatrixf, (m));
}

KEYWORD1 void KEYWORD2 NAME(LoadName)(GLuint name)
{
   DISPATCH_SETUP;
   DISPATCH(LoadName, (name));
}

KEYWORD1 void KEYWORD2 NAME(LogicOp)(GLenum opcode)
{
   DISPATCH_SETUP;
   DISPATCH(LogicOp, (opcode));
}

KEYWORD1 void KEYWORD2 NAME(Map1d)(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   DISPATCH_SETUP;
   DISPATCH(Map1d, (target, u1, u2, stride, order, points));
}

KEYWORD1 void KEYWORD2 NAME(Map1f)(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   DISPATCH_SETUP;
   DISPATCH(Map1f, (target, u1, u2, stride, order, points));
}

KEYWORD1 void KEYWORD2 NAME(Map2d)(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   DISPATCH_SETUP;
   DISPATCH(Map2d, (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points));
}

KEYWORD1 void KEYWORD2 NAME(Map2f)(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   DISPATCH_SETUP;
   DISPATCH(Map2f, (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points));
}

KEYWORD1 void KEYWORD2 NAME(MapGrid1d)(GLint un, GLdouble u1, GLdouble u2)
{
   DISPATCH_SETUP;
   DISPATCH(MapGrid1d, (un, u1, u2));
}

KEYWORD1 void KEYWORD2 NAME(MapGrid1f)(GLint un, GLfloat u1, GLfloat u2)
{
   DISPATCH_SETUP;
   DISPATCH(MapGrid1f, (un, u1, u2));
}

KEYWORD1 void KEYWORD2 NAME(MapGrid2d)(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)
{
   DISPATCH_SETUP;
   DISPATCH(MapGrid2d, (un, u1, u2, vn, v1, v2));
}

KEYWORD1 void KEYWORD2 NAME(MapGrid2f)(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)
{
   DISPATCH_SETUP;
   DISPATCH(MapGrid2f, (un, u1, u2, vn, v1, v2));
}

KEYWORD1 void KEYWORD2 NAME(Materialf)(GLenum face, GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(Materialf, (face, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(Materiali)(GLenum face, GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(Materiali, (face, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(Materialfv)(GLenum face, GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(Materialfv, (face, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(Materialiv)(GLenum face, GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(Materialiv, (face, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(MatrixMode)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(MatrixMode, (mode));
}

KEYWORD1 void KEYWORD2 NAME(MultMatrixd)(const GLdouble *m)
{
   DISPATCH_SETUP;
   DISPATCH(MultMatrixd, (m));
}

KEYWORD1 void KEYWORD2 NAME(MultMatrixf)(const GLfloat *m)
{
   DISPATCH_SETUP;
   DISPATCH(MultMatrixf, (m));
}

KEYWORD1 void KEYWORD2 NAME(NewList)(GLuint list, GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(NewList, (list, mode));
}

KEYWORD1 void KEYWORD2 NAME(Normal3b)(GLbyte nx, GLbyte ny, GLbyte nz)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3b, (nx, ny, nz));
}

KEYWORD1 void KEYWORD2 NAME(Normal3bv)(const GLbyte *v)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3bv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Normal3d)(GLdouble nx, GLdouble ny, GLdouble nz)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3d, (nx, ny, nz));
}

KEYWORD1 void KEYWORD2 NAME(Normal3dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Normal3f)(GLfloat nx, GLfloat ny, GLfloat nz)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3f, (nx, ny, nz));
}

KEYWORD1 void KEYWORD2 NAME(Normal3fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Normal3i)(GLint nx, GLint ny, GLint nz)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3i, (nx, ny, nz));
}

KEYWORD1 void KEYWORD2 NAME(Normal3iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Normal3s)(GLshort nx, GLshort ny, GLshort nz)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3s, (nx, ny, nz));
}

KEYWORD1 void KEYWORD2 NAME(Normal3sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Normal3sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Ortho)(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble nearval, GLdouble farval)
{
   DISPATCH_SETUP;
   DISPATCH(Ortho, (left, right, bottom, top, nearval, farval));
}

KEYWORD1 void KEYWORD2 NAME(PassThrough)(GLfloat token)
{
   DISPATCH_SETUP;
   DISPATCH(PassThrough, (token));
}

KEYWORD1 void KEYWORD2 NAME(PixelMapfv)(GLenum map, GLint mapsize, const GLfloat *values)
{
   DISPATCH_SETUP;
   DISPATCH(PixelMapfv, (map, mapsize, values));
}

KEYWORD1 void KEYWORD2 NAME(PixelMapuiv)(GLenum map, GLint mapsize, const GLuint *values)
{
   DISPATCH_SETUP;
   DISPATCH(PixelMapuiv, (map, mapsize, values));
}

KEYWORD1 void KEYWORD2 NAME(PixelMapusv)(GLenum map, GLint mapsize, const GLushort *values)
{
   DISPATCH_SETUP;
   DISPATCH(PixelMapusv, (map, mapsize, values));
}

KEYWORD1 void KEYWORD2 NAME(PixelStoref)(GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(PixelStoref, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(PixelStorei)(GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(PixelStorei, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(PixelTransferf)(GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(PixelTransferf, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(PixelTransferi)(GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(PixelTransferi, (pname, param));
}

KEYWORD1 void KEYWORD2 NAME(PixelZoom)(GLfloat xfactor, GLfloat yfactor)
{
   DISPATCH_SETUP;
   DISPATCH(PixelZoom, (xfactor, yfactor));
}

KEYWORD1 void KEYWORD2 NAME(PointSize)(GLfloat size)
{
   DISPATCH_SETUP;
   DISPATCH(PointSize, (size));
}

KEYWORD1 void KEYWORD2 NAME(PolygonMode)(GLenum face, GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(PolygonMode, (face, mode));
}

KEYWORD1 void KEYWORD2 NAME(PolygonStipple)(const GLubyte *pattern)
{
   DISPATCH_SETUP;
   DISPATCH(PolygonStipple, (pattern));
}

KEYWORD1 void KEYWORD2 NAME(PopAttrib)(void)
{
   DISPATCH_SETUP;
   DISPATCH(PopAttrib, ());
}

KEYWORD1 void KEYWORD2 NAME(PopMatrix)(void)
{
   DISPATCH_SETUP;
   DISPATCH(PopMatrix, ());
}

KEYWORD1 void KEYWORD2 NAME(PopName)(void)
{
   DISPATCH_SETUP;
   DISPATCH(PopName, ());
}

KEYWORD1 void KEYWORD2 NAME(PushAttrib)(GLbitfield mask)
{
   DISPATCH_SETUP;
   DISPATCH(PushAttrib, (mask));
}

KEYWORD1 void KEYWORD2 NAME(PushMatrix)(void)
{
   DISPATCH_SETUP;
   DISPATCH(PushMatrix, ());
}

KEYWORD1 void KEYWORD2 NAME(PushName)(GLuint name)
{
   DISPATCH_SETUP;
   DISPATCH(PushName, (name));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2d)(GLdouble x, GLdouble y)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2d, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2f)(GLfloat x, GLfloat y)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2f, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2i)(GLint x, GLint y)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2i, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2s)(GLshort x, GLshort y)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2s, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3d)(GLdouble x, GLdouble y, GLdouble z)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3d, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3f)(GLfloat x, GLfloat y, GLfloat z)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3f, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3i)(GLint x, GLint y, GLint z)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3i, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3s)(GLshort x, GLshort y, GLshort z)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3s, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4d)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4d, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4f)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4f, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4i)(GLint x, GLint y, GLint z, GLint w)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4i, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4s)(GLshort x, GLshort y, GLshort z, GLshort w)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4s, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos2sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos2sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos3sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos3sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(RasterPos4sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(RasterPos4sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(ReadBuffer)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(ReadBuffer, (mode));
}

KEYWORD1 void KEYWORD2 NAME(ReadPixels)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(ReadPixels, (x, y, width, height, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(Rectd)(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
   DISPATCH_SETUP;
   DISPATCH(Rectd, (x1, y1, x2, y2));
}

KEYWORD1 void KEYWORD2 NAME(Rectdv)(const GLdouble *v1, const GLdouble *v2)
{
   DISPATCH_SETUP;
   DISPATCH(Rectdv, (v1, v2));
}

KEYWORD1 void KEYWORD2 NAME(Rectf)(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)
{
   DISPATCH_SETUP;
   DISPATCH(Rectf, (x1, y1, x2, y2));
}

KEYWORD1 void KEYWORD2 NAME(Rectfv)(const GLfloat *v1, const GLfloat *v2)
{
   DISPATCH_SETUP;
   DISPATCH(Rectfv, (v1, v2));
}

KEYWORD1 void KEYWORD2 NAME(Recti)(GLint x1, GLint y1, GLint x2, GLint y2)
{
   DISPATCH_SETUP;
   DISPATCH(Recti, (x1, y1, x2, y2));
}

KEYWORD1 void KEYWORD2 NAME(Rectiv)(const GLint *v1, const GLint *v2)
{
   DISPATCH_SETUP;
   DISPATCH(Rectiv, (v1, v2));
}

KEYWORD1 void KEYWORD2 NAME(Rects)(GLshort x1, GLshort y1, GLshort x2, GLshort y2)
{
   DISPATCH_SETUP;
   DISPATCH(Rects, (x1, y1, x2, y2));
}

KEYWORD1 void KEYWORD2 NAME(Rectsv)(const GLshort *v1, const GLshort *v2)
{
   DISPATCH_SETUP;
   DISPATCH(Rectsv, (v1, v2));
}

KEYWORD1 GLint KEYWORD2 NAME(RenderMode)(GLenum mode)
{
   DISPATCH_SETUP;
   return DISPATCH(RenderMode, (mode));
}

KEYWORD1 void KEYWORD2 NAME(Rotated)(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   DISPATCH_SETUP;
   DISPATCH(Rotated, (angle, x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Rotatef)(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   DISPATCH_SETUP;
   DISPATCH(Rotatef, (angle, x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(SelectBuffer)(GLsizei size, GLuint *buffer)
{
   DISPATCH_SETUP;
   DISPATCH(SelectBuffer, (size, buffer));
}

KEYWORD1 void KEYWORD2 NAME(Scaled)(GLdouble x, GLdouble y, GLdouble z)
{
   DISPATCH_SETUP;
   DISPATCH(Scaled, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Scalef)(GLfloat x, GLfloat y, GLfloat z)
{
   DISPATCH_SETUP;
   DISPATCH(Scalef, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Scissor)(GLint x, GLint y, GLsizei width, GLsizei height)
{
   DISPATCH_SETUP;
   DISPATCH(Scissor, (x, y, width, height));
}

KEYWORD1 void KEYWORD2 NAME(ShadeModel)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(ShadeModel, (mode));
}

KEYWORD1 void KEYWORD2 NAME(StencilFunc)(GLenum func, GLint ref, GLuint mask)
{
   DISPATCH_SETUP;
   DISPATCH(StencilFunc, (func, ref, mask));
}

KEYWORD1 void KEYWORD2 NAME(StencilMask)(GLuint mask)
{
   DISPATCH_SETUP;
   DISPATCH(StencilMask, (mask));
}

KEYWORD1 void KEYWORD2 NAME(StencilOp)(GLenum fail, GLenum zfail, GLenum zpass)
{
   DISPATCH_SETUP;
   DISPATCH(StencilOp, (fail, zfail, zpass));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1d)(GLdouble s)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1d, (s));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1f)(GLfloat s)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1f, (s));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1i)(GLint s)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1i, (s));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1s)(GLshort s)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1s, (s));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2d)(GLdouble s, GLdouble t)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2d, (s, t));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2f)(GLfloat s, GLfloat t)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2f, (s, t));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2s)(GLshort s, GLshort t)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2s, (s, t));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2i)(GLint s, GLint t)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2i, (s, t));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3d)(GLdouble s, GLdouble t, GLdouble r)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3d, (s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3f)(GLfloat s, GLfloat t, GLfloat r)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3f, (s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3i)(GLint s, GLint t, GLint r)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3i, (s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3s)(GLshort s, GLshort t, GLshort r)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3s, (s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4d)(GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4d, (s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4f)(GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4f, (s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4i)(GLint s, GLint t, GLint r, GLint q)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4i, (s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4s)(GLshort s, GLshort t, GLshort r, GLshort q)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4s, (s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord1sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord1sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord2sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord2sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord3sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord3sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexCoord4sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoord4sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(TexGend)(GLenum coord, GLenum pname, GLdouble param)
{
   DISPATCH_SETUP;
   DISPATCH(TexGend, (coord, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexGendv)(GLenum coord, GLenum pname, const GLdouble *params)
{
   DISPATCH_SETUP;
   DISPATCH(TexGendv, (coord, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(TexGenf)(GLenum coord, GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(TexGenf, (coord, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexGenfv)(GLenum coord, GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(TexGenfv, (coord, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(TexGeni)(GLenum coord, GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(TexGeni, (coord, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexGeniv)(GLenum coord, GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(TexGeniv, (coord, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(TexEnvf)(GLenum target, GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(TexEnvf, (target, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexEnvfv)(GLenum target, GLenum pname, const GLfloat *param)
{
   DISPATCH_SETUP;
   DISPATCH(TexEnvfv, (target, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexEnvi)(GLenum target, GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(TexEnvi, (target, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexEnviv)(GLenum target, GLenum pname, const GLint *param)
{
   DISPATCH_SETUP;
   DISPATCH(TexEnviv, (target, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexImage1D)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexImage1D, (target, level, internalformat, width, border, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(TexImage2D)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexImage2D, (target, level, internalformat, width, height, border, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(TexParameterf)(GLenum target, GLenum pname, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(TexParameterf, (target, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexParameterfv)(GLenum target, GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(TexParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(TexParameteri)(GLenum target, GLenum pname, GLint param)
{
   DISPATCH_SETUP;
   DISPATCH(TexParameteri, (target, pname, param));
}

KEYWORD1 void KEYWORD2 NAME(TexParameteriv)(GLenum target, GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(TexParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(Translated)(GLdouble x, GLdouble y, GLdouble z)
{
   DISPATCH_SETUP;
   DISPATCH(Translated, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Translatef)(GLfloat x, GLfloat y, GLfloat z)
{
   DISPATCH_SETUP;
   DISPATCH(Translatef, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2d)(GLdouble x, GLdouble y)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2d, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2f)(GLfloat x, GLfloat y)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2f, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2i)(GLint x, GLint y)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2i, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2s)(GLshort x, GLshort y)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2s, (x, y));
}

KEYWORD1 void KEYWORD2 NAME(Vertex2sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex2sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3d)(GLdouble x, GLdouble y, GLdouble z)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3d, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3f)(GLfloat x, GLfloat y, GLfloat z)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3f, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3i)(GLint x, GLint y, GLint z)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3i, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3s)(GLshort x, GLshort y, GLshort z)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3s, (x, y, z));
}

KEYWORD1 void KEYWORD2 NAME(Vertex3sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex3sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4d)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4d, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4dv)(const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4dv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4f)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4f, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4fv)(const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4fv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4i)(GLint x, GLint y, GLint z, GLint w)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4i, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4iv)(const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4iv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4s)(GLshort x, GLshort y, GLshort z, GLshort w)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4s, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(Vertex4sv)(const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(Vertex4sv, (v));
}

KEYWORD1 void KEYWORD2 NAME(Viewport)(GLint x, GLint y, GLsizei width, GLsizei height)
{
   DISPATCH_SETUP;
   DISPATCH(Viewport, (x, y, width, height));
}




#ifdef _GLAPI_VERSION_1_1

KEYWORD1 GLboolean KEYWORD2 NAME(AreTexturesResident)(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   DISPATCH_SETUP;
   return DISPATCH(AreTexturesResident, (n, textures, residences));
}

KEYWORD1 void KEYWORD2 NAME(ArrayElement)(GLint i)
{
   DISPATCH_SETUP;
   DISPATCH(ArrayElement, (i));
}

KEYWORD1 void KEYWORD2 NAME(BindTexture)(GLenum target, GLuint texture)
{
   DISPATCH_SETUP;
   DISPATCH(BindTexture, (target, texture));
}

KEYWORD1 void KEYWORD2 NAME(ColorPointer)(GLint size, GLenum type, GLsizei stride, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   DISPATCH(ColorPointer, (size, type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(CopyTexImage1D)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   DISPATCH_SETUP;
   DISPATCH(CopyTexImage1D, (target, level, internalformat, x, y, width, border));
}

KEYWORD1 void KEYWORD2 NAME(CopyTexImage2D)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   DISPATCH_SETUP;
   DISPATCH(CopyTexImage2D, (target, level, internalformat, x, y, width, height, border));
}

KEYWORD1 void KEYWORD2 NAME(CopyTexSubImage1D)(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   DISPATCH_SETUP;
   DISPATCH(CopyTexSubImage1D, (target, level, xoffset, x, y, width));
}

KEYWORD1 void KEYWORD2 NAME(CopyTexSubImage2D)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   DISPATCH_SETUP;
   DISPATCH(CopyTexSubImage2D, (target, level, xoffset, yoffset, x, y, width, height));
}

KEYWORD1 void KEYWORD2 NAME(DeleteTextures)(GLsizei n, const GLuint *textures)
{
   DISPATCH_SETUP;
   DISPATCH(DeleteTextures, (n, textures));
}

KEYWORD1 void KEYWORD2 NAME(DisableClientState)(GLenum cap)
{
   DISPATCH_SETUP;
   DISPATCH(DisableClientState, (cap));
}

KEYWORD1 void KEYWORD2 NAME(DrawArrays)(GLenum mode, GLint first, GLsizei count)
{
   DISPATCH_SETUP;
   DISPATCH(DrawArrays, (mode, first, count));
}

KEYWORD1 void KEYWORD2 NAME(EdgeFlagPointer)(GLsizei stride, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   DISPATCH(EdgeFlagPointer, (stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(EnableClientState)(GLenum cap)
{
   DISPATCH_SETUP;
   DISPATCH(EnableClientState, (cap));
}

KEYWORD1 void KEYWORD2 NAME(GenTextures)(GLsizei n, GLuint *textures)
{
   DISPATCH_SETUP;
   DISPATCH(GenTextures, (n, textures));
}

KEYWORD1 void KEYWORD2 NAME(GetPointerv)(GLenum pname, GLvoid **params)
{
   DISPATCH_SETUP;
   DISPATCH(GetPointerv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(IndexPointer)(GLenum type, GLsizei stride, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   DISPATCH(IndexPointer, (type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(NormalPointer)(GLenum type, GLsizei stride, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   DISPATCH(NormalPointer, (type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(PolygonOffset)(GLfloat factor, GLfloat units)
{
   DISPATCH_SETUP;
   DISPATCH(PolygonOffset, (factor, units));
}

KEYWORD1 void KEYWORD2 NAME(PopClientAttrib)(void)
{
   DISPATCH_SETUP;
   DISPATCH(PopClientAttrib, ());
}

KEYWORD1 void KEYWORD2 NAME(PrioritizeTextures)(GLsizei n, const GLuint *textures, const GLclampf *priorities)
{
   DISPATCH_SETUP;
   DISPATCH(PrioritizeTextures, (n, textures, priorities));
}

KEYWORD1 void KEYWORD2 NAME(PushClientAttrib)(GLbitfield mask)
{
   DISPATCH_SETUP;
   DISPATCH(PushClientAttrib, (mask));
}

KEYWORD1 void KEYWORD2 NAME(TexCoordPointer)(GLint size, GLenum type, GLsizei stride, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   DISPATCH(TexCoordPointer, (size, type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(TexSubImage1D)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexSubImage1D, (target, level, xoffset, width, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(TexSubImage2D)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexSubImage2D, (target, level, xoffset, yoffset, width, height, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(VertexPointer)(GLint size, GLenum type, GLsizei stride, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   DISPATCH(VertexPointer, (size, type, stride, ptr));
}

#endif  /*_GLAPI_VERSION_1_1*/



#ifdef _GLAPI_VERSION_1_2

KEYWORD1 void KEYWORD2 NAME(CopyTexSubImage3D)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   DISPATCH_SETUP;
   DISPATCH(CopyTexSubImage3D, (target, level, xoffset, yoffset, zoffset, x, y, width, height));
}

KEYWORD1 void KEYWORD2 NAME(DrawRangeElements)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const GLvoid *indices)
{
   DISPATCH_SETUP;
   DISPATCH(DrawRangeElements, (mode, start, end, count, type, indices));
}

KEYWORD1 void KEYWORD2 NAME(TexImage3D)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexImage3D, (target, level, internalformat, width, height, depth, border, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(TexSubImage3D)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexSubImage3D, (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels));
}


#ifdef _GLAPI_ARB_imaging

KEYWORD1 void KEYWORD2 NAME(BlendColor)(GLclampf r, GLclampf g, GLclampf b, GLclampf a)
{
   DISPATCH_SETUP;
   DISPATCH(BlendColor, (r, g, b, a));
}

KEYWORD1 void KEYWORD2 NAME(BlendEquation)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(BlendEquation, (mode));
}

KEYWORD1 void KEYWORD2 NAME(ColorSubTable)(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const GLvoid *data)
{
   DISPATCH_SETUP;
   DISPATCH(ColorSubTable, (target, start, count, format, type, data));
}

KEYWORD1 void KEYWORD2 NAME(ColorTable)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid *table)
{
   DISPATCH_SETUP;
   DISPATCH(ColorTable, (target, internalformat, width, format, type, table));
}

KEYWORD1 void KEYWORD2 NAME(ColorTableParameterfv)(GLenum target, GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(ColorTableParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(ColorTableParameteriv)(GLenum target, GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(ColorTableParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(ConvolutionFilter1D)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid *image)
{
   DISPATCH_SETUP;
   DISPATCH(ConvolutionFilter1D, (target, internalformat, width, format, type, image));
}

KEYWORD1 void KEYWORD2 NAME(ConvolutionFilter2D)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *image)
{
   DISPATCH_SETUP;
   DISPATCH(ConvolutionFilter2D, (target, internalformat, width, height, format, type, image));
}

KEYWORD1 void KEYWORD2 NAME(ConvolutionParameterf)(GLenum target, GLenum pname, GLfloat params)
{
   DISPATCH_SETUP;
   DISPATCH(ConvolutionParameterf, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(ConvolutionParameterfv)(GLenum target, GLenum pname, const GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(ConvolutionParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(ConvolutionParameteri)(GLenum target, GLenum pname, GLint params)
{
   DISPATCH_SETUP;
   DISPATCH(ConvolutionParameteri, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(ConvolutionParameteriv)(GLenum target, GLenum pname, const GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(ConvolutionParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(CopyColorSubTable)(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)
{
   DISPATCH_SETUP;
   DISPATCH(CopyColorSubTable, (target, start, x, y, width));
}

KEYWORD1 void KEYWORD2 NAME(CopyColorTable)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   DISPATCH_SETUP;
   DISPATCH(CopyColorTable, (target, internalformat, x, y, width));
}

KEYWORD1 void KEYWORD2 NAME(CopyConvolutionFilter1D)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   DISPATCH_SETUP;
   DISPATCH(CopyConvolutionFilter1D, (target, internalformat, x, y, width));
}

KEYWORD1 void KEYWORD2 NAME(CopyConvolutionFilter2D)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)
{
   DISPATCH_SETUP;
   DISPATCH(CopyConvolutionFilter2D, (target, internalformat, x, y, width, height));
}

KEYWORD1 void KEYWORD2 NAME(GetColorTable)(GLenum target, GLenum format, GLenum type, GLvoid *table)
{
   DISPATCH_SETUP;
   DISPATCH(GetColorTable, (target, format, type, table));
}

KEYWORD1 void KEYWORD2 NAME(GetColorTableParameterfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetColorTableParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetColorTableParameteriv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetColorTableParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetConvolutionFilter)(GLenum target, GLenum format, GLenum type, GLvoid *image)
{
   DISPATCH_SETUP;
   DISPATCH(GetConvolutionFilter, (target, format, type, image));
}

KEYWORD1 void KEYWORD2 NAME(GetConvolutionParameterfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetConvolutionParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetConvolutionParameteriv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetConvolutionParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetHistogram)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLvoid *values)
{
   DISPATCH_SETUP;
   DISPATCH(GetHistogram, (target, reset, format, type, values));
}

KEYWORD1 void KEYWORD2 NAME(GetHistogramParameterfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetHistogramParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetHistogramParameteriv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetHistogramParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetMinmax)(GLenum target, GLboolean reset, GLenum format, GLenum types, GLvoid *values)
{
   DISPATCH_SETUP;
   DISPATCH(GetMinmax, (target, reset, format, types, values));
}

KEYWORD1 void KEYWORD2 NAME(GetMinmaxParameterfv)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetMinmaxParameterfv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetMinmaxParameteriv)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetMinmaxParameteriv, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetSeparableFilter)(GLenum target, GLenum format, GLenum type, GLvoid *row, GLvoid *column, GLvoid *span)
{
   DISPATCH_SETUP;
   DISPATCH(GetSeparableFilter, (target, format, type, row, column, span));
}

KEYWORD1 void KEYWORD2 NAME(Histogram)(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
{
   DISPATCH_SETUP;
   DISPATCH(Histogram, (target, width, internalformat, sink));
}

KEYWORD1 void KEYWORD2 NAME(Minmax)(GLenum target, GLenum internalformat, GLboolean sink)
{
   DISPATCH_SETUP;
   DISPATCH(Minmax, (target, internalformat, sink));
}

KEYWORD1 void KEYWORD2 NAME(ResetMinmax)(GLenum target)
{
   DISPATCH_SETUP;
   DISPATCH(ResetMinmax, (target));
}

KEYWORD1 void KEYWORD2 NAME(ResetHistogram)(GLenum target)
{
   DISPATCH_SETUP;
   DISPATCH(ResetHistogram, (target));
}

KEYWORD1 void KEYWORD2 NAME(SeparableFilter2D)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *row, const GLvoid *column)
{
   DISPATCH_SETUP;
   DISPATCH(SeparableFilter2D, (target, internalformat, width, height, format, type, row, column));
}


#endif  /*_GLAPI_ARB_imaging*/
#endif  /*_GLAPI_VERSION_1_2*/



/***
 *** Extension functions
 ***/

#ifdef _GLAPI_EXT_blend_minmax
KEYWORD1 void KEYWORD2 NAME(BlendEquationEXT)(GLenum mode)
{
   DISPATCH_SETUP;
   DISPATCH(BlendEquationEXT, (mode));
}
#endif


#ifdef _GLAPI_EXT_blend_color
KEYWORD1 void KEYWORD2 NAME(BlendColorEXT)(GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha)
{
   DISPATCH_SETUP;
   DISPATCH(BlendColorEXT, (red, green, blue, alpha));
}
#endif


#ifdef _GLAPI_EXT_polygon_offset
KEYWORD1 void KEYWORD2 NAME(PolygonOffsetEXT)(GLfloat factor, GLfloat bias)
{
   DISPATCH_SETUP;
   DISPATCH(PolygonOffsetEXT, (factor, bias));
}
#endif



#ifdef _GLAPI_EXT_vertex_array

KEYWORD1 void KEYWORD2 NAME(VertexPointerEXT)(GLint size, GLenum type, GLsizei stride, GLsizei count, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   (void) count;
   DISPATCH(VertexPointer, (size, type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(NormalPointerEXT)(GLenum type, GLsizei stride, GLsizei count, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   (void) count;
   DISPATCH(NormalPointer, (type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(ColorPointerEXT)(GLint size, GLenum type, GLsizei stride, GLsizei count, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   (void) count;
   DISPATCH(ColorPointer, (size, type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(IndexPointerEXT)(GLenum type, GLsizei stride, GLsizei count, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   (void) count;
   DISPATCH(IndexPointer, (type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(TexCoordPointerEXT)(GLint size, GLenum type, GLsizei stride, GLsizei count, const GLvoid *ptr)
{
   DISPATCH_SETUP;
   (void) count;
   DISPATCH(ColorPointer, (size, type, stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(EdgeFlagPointerEXT)(GLsizei stride, GLsizei count, const GLboolean *ptr)
{
   DISPATCH_SETUP;
   (void) count;
   DISPATCH(EdgeFlagPointer, (stride, ptr));
}

KEYWORD1 void KEYWORD2 NAME(GetPointervEXT)(GLenum pname, void **params)
{
   DISPATCH_SETUP;
   DISPATCH(GetPointerv, (pname, params));
}

KEYWORD1 void KEYWORD2 NAME(ArrayElementEXT)(GLint i)
{
   DISPATCH_SETUP;
   DISPATCH(ArrayElement, (i));
}

KEYWORD1 void KEYWORD2 NAME(DrawArraysEXT)(GLenum mode, GLint first, GLsizei count)
{
   DISPATCH_SETUP;
   DISPATCH(DrawArrays, (mode, first, count));
}

#endif  /* GL_EXT_vertex_arrays */



#ifdef _GLAPI_EXT_texture_object

KEYWORD1 void KEYWORD2 NAME(GenTexturesEXT)(GLsizei n, GLuint *textures)
{
   DISPATCH_SETUP;
   DISPATCH(GenTextures, (n, textures));
}

KEYWORD1 void KEYWORD2 NAME(DeleteTexturesEXT)(GLsizei n, const GLuint *texture)
{
   DISPATCH_SETUP;
   DISPATCH(DeleteTextures, (n, texture));
}

KEYWORD1 void KEYWORD2 NAME(BindTextureEXT)(GLenum target, GLuint texture)
{
   DISPATCH_SETUP;
   DISPATCH(BindTexture, (target, texture));
}

KEYWORD1 void KEYWORD2 NAME(PrioritizeTexturesEXT)(GLsizei n, const GLuint *textures, const GLclampf *priorities)
{
   DISPATCH_SETUP;
   DISPATCH(PrioritizeTextures, (n, textures, priorities));
}

KEYWORD1 GLboolean KEYWORD2 NAME(AreTexturesResidentEXT)(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   DISPATCH_SETUP;
   DISPATCH(AreTexturesResident, (n, textures, residences));
   return GL_FALSE;
}

KEYWORD1 GLboolean KEYWORD2 NAME(IsTextureEXT)(GLuint texture)
{
   DISPATCH_SETUP;
   DISPATCH(IsTexture, (texture));
   return GL_FALSE;
}
#endif  /* GL_EXT_texture_object */



#ifdef _GLAPI_EXT_texture3D

KEYWORD1 void KEYWORD2 NAME(TexImage3DEXT)(GLenum target, GLint level, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexImage3D, (target, level, internalFormat, width, height, depth, border, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(TexSubImage3DEXT)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const GLvoid *pixels)
{
   DISPATCH_SETUP;
   DISPATCH(TexSubImage3D, (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels));
}

KEYWORD1 void KEYWORD2 NAME(CopyTexSubImage3DEXT)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   DISPATCH_SETUP;
   DISPATCH(CopyTexSubImage3D, (target, level, xoffset, yoffset, zoffset, x, y, width, height));
}

#endif  /* GL_EXT_texture3D*/



#ifdef _GLAPI_EXT_paletted_texture

KEYWORD1 void KEYWORD2 NAME(ColorTableEXT)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid *table)
{
   DISPATCH_SETUP;
   DISPATCH(ColorTableEXT, (target, internalformat, width, format, type, table));
}

KEYWORD1 void KEYWORD2 NAME(ColorSubTableEXT)(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const GLvoid *data)
{
   DISPATCH_SETUP;
   DISPATCH(ColorSubTableEXT, (target, start, count, format, type, data));
}

KEYWORD1 void KEYWORD2 NAME(GetColorTableEXT)(GLenum target, GLenum format, GLenum type, GLvoid *table)
{
   DISPATCH_SETUP;
   DISPATCH(GetColorTableEXT, (target, format, type, table));
}

KEYWORD1 void KEYWORD2 NAME(GetColorTableParameterfvEXT)(GLenum target, GLenum pname, GLfloat *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetColorTableParameterfvEXT, (target, pname, params));
}

KEYWORD1 void KEYWORD2 NAME(GetColorTableParameterivEXT)(GLenum target, GLenum pname, GLint *params)
{
   DISPATCH_SETUP;
   DISPATCH(GetColorTableParameterivEXT, (target, pname, params));
}

#endif  /* GL_EXT_paletted_texture */



#ifdef _GLAPI_EXT_compiled_vertex_array

KEYWORD1 void KEYWORD2 NAME(LockArraysEXT)(GLint first, GLsizei count)
{
   DISPATCH_SETUP;
   DISPATCH(LockArraysEXT, (first, count));
}

KEYWORD1 void KEYWORD2 NAME(UnlockArraysEXT)(void)
{
   DISPATCH_SETUP;
   DISPATCH(UnlockArraysEXT, ());
}

#endif  /* GL_EXT_compiled_vertex_array */



#ifdef _GLAPI_EXT_point_parameters

KEYWORD1 void KEYWORD2 NAME(PointParameterfEXT)(GLenum target, GLfloat param)
{
   DISPATCH_SETUP;
   DISPATCH(PointParameterfEXT, (target, param));
}

KEYWORD1 void KEYWORD2 NAME(PointParameterfvEXT)(GLenum target, const GLfloat *param)
{
   DISPATCH_SETUP;
   DISPATCH(PointParameterfvEXT, (target, param));
}

#endif  /* GL_EXT_point_parameters */



#ifdef _GLAPI_ARB_multitexture

KEYWORD1 void KEYWORD2 NAME(ActiveTextureARB)(GLenum texture)
{
   DISPATCH_SETUP;
   DISPATCH(ActiveTextureARB, (texture));
}

KEYWORD1 void KEYWORD2 NAME(ClientActiveTextureARB)(GLenum texture)
{
   DISPATCH_SETUP;
   DISPATCH(ClientActiveTextureARB, (texture));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1dARB)(GLenum target, GLdouble s)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1dARB, (target, s));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1dvARB)(GLenum target, const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1dvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1fARB)(GLenum target, GLfloat s)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1fARB, (target, s));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1fvARB)(GLenum target, const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1fvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1iARB)(GLenum target, GLint s)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1iARB, (target, s));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1ivARB)(GLenum target, const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1ivARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1sARB)(GLenum target, GLshort s)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1sARB, (target, s));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord1svARB)(GLenum target, const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord1svARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2dARB)(GLenum target, GLdouble s, GLdouble t)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2dARB, (target, s, t));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2dvARB)(GLenum target, const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2dvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2fARB)(GLenum target, GLfloat s, GLfloat t)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2fARB, (target, s, t));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2fvARB)(GLenum target, const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2fvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2iARB)(GLenum target, GLint s, GLint t)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2iARB, (target, s, t));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2ivARB)(GLenum target, const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2ivARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2sARB)(GLenum target, GLshort s, GLshort t)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2sARB, (target, s, t));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord2svARB)(GLenum target, const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord2svARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3dARB)(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3dARB, (target, s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3dvARB)(GLenum target, const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3dvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3fARB)(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3fARB, (target, s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3fvARB)(GLenum target, const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3fvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3iARB)(GLenum target, GLint s, GLint t, GLint r)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3iARB, (target, s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3ivARB)(GLenum target, const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3ivARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3sARB)(GLenum target, GLshort s, GLshort t, GLshort r)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3sARB, (target, s, t, r));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord3svARB)(GLenum target, const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord3svARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4dARB)(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4dARB, (target, s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4dvARB)(GLenum target, const GLdouble *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4dvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4fARB)(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4fARB, (target, s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4fvARB)(GLenum target, const GLfloat *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4fvARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4iARB)(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4iARB, (target, s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4ivARB)(GLenum target, const GLint *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4ivARB, (target, v));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4sARB)(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4sARB, (target, s, t, r, q));
}

KEYWORD1 void KEYWORD2 NAME(MultiTexCoord4svARB)(GLenum target, const GLshort *v)
{
   DISPATCH_SETUP;
   DISPATCH(MultiTexCoord4svARB, (target, v));
}

#endif  /* GL_ARB_multitexture */



#ifdef _GLAPI_INGR_blend_func_separate
KEYWORD1 void KEYWORD2 NAME(BlendFuncSeparateINGR)(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   DISPATCH_SETUP;
   DISPATCH(BlendFuncSeparateINGR, (sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha));
}
#endif  /* GL_INGR_blend_func_separate */



#ifdef _GLAPI_MESA_window_pos

KEYWORD1 void KEYWORD2 NAME(WindowPos2iMESA)(GLint x, GLint y)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2sMESA)(GLshort x, GLshort y)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2fMESA)(GLfloat x, GLfloat y)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2dMESA)(GLdouble x, GLdouble y)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2ivMESA)(const GLint *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2svMESA)(const GLshort *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2fvMESA)(const GLfloat *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos2dvMESA)(const GLdouble *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], 0, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3iMESA)(GLint x, GLint y, GLint z)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3sMESA)(GLshort x, GLshort y, GLshort z)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3fMESA)(GLfloat x, GLfloat y, GLfloat z)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3dMESA)(GLdouble x, GLdouble y, GLdouble z)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, 1));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3ivMESA)(const GLint *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], 1.0));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3svMESA)(const GLshort *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], 1.0));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3fvMESA)(const GLfloat *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], 1.0));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos3dvMESA)(const GLdouble *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], 1.0));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4iMESA)(GLint x, GLint y, GLint z, GLint w)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4sMESA)(GLshort x, GLshort y, GLshort z, GLshort w)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4fMESA)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4dMESA)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (x, y, z, w));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4ivMESA)(const GLint *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], p[3]));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4svMESA)(const GLshort *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], p[3]));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4fvMESA)(const GLfloat *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], p[3]));
}

KEYWORD1 void KEYWORD2 NAME(WindowPos4dvMESA)(const GLdouble *p)
{
   DISPATCH_SETUP;
   DISPATCH(WindowPos4fMESA, (p[0], p[1], p[2], p[3]));
}

#endif  /* GL_MESA_window_pos */


#ifdef _GLAPI_MESA_resize_buffers
KEYWORD1 void KEYWORD2 NAME(ResizeBuffersMESA)(void)
{
   DISPATCH_SETUP;
   DISPATCH(ResizeBuffersMESA, ());
}
#endif  /* GL_MESA_resize_buffers */



#undef KEYWORD1
#undef KEYWORD2
#undef NAME
#undef DISPATCH_SETUP
#undef DISPATCH
